@@ -49,14 +49,12 @@ See L<Mojolicious::Plugin::AssetPack::Preprocessor/process>.
 sub process {
   my ($self, $assetpack, $text, $path) = @_;
   my @cmd = ($self->executable, '--stdin', '--scss');
-  my $err;
 
   push @cmd, '-I' => dirname $path;
   push @cmd, qw( -t compressed) if $assetpack->minify;
   push @cmd, qw( --compass ) if !$ENV{MOJO_ASSETPACK_NO_COMPASS} and $$text =~ m!\@import\W+compass\/!;
 
-  $self->_run(\@cmd, $text, $text, \$err);
-  $self->_make_css_error($err, $text) if length $err;
+  $self->_run(\@cmd, $text, $text);
 }
 
 sub _extension {'scss'}
